@@ -227,10 +227,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif // HAVE_CONFIG_H
-
-// FIXME: get rid of this define. We should fix up the compile issues
-// wrt Qt 4 properly. 20050629 mortene.
-#define QT3_SUPPORT
+#include <qt-config.h>
 
 #include <stdlib.h>
 #include <limits.h>
@@ -278,12 +275,8 @@
 #include <Inventor/Qt/SoAny.h>
 #include <Inventor/Qt/SoQtInternal.h>
 
-#include <Inventor/Qt/nodes/SoGuiNodes.h>
-#include <Inventor/Qt/engines/SoGuiEngines.h>
-
 #include <soqtdefs.h>
 
-
 // *************************************************************************
 
 // The private data for the SoQt class.
@@ -299,6 +292,8 @@ QTimer * SoQtP::delaytimeouttimer = NULL;
 SoQtP * SoQtP::slotobj = NULL;
 bool SoQtP::didcreatemainwidget = FALSE;
 
+// *************************************************************************
+
 #ifdef HAVE_QT_WIN_USE_SIMPLE_TIMERS
 // Qt 3.3 seems to use simple timers by default. Since simple timers
 // causes idle sensors to trigger only 100 times per second, we set
@@ -323,6 +318,8 @@ static void soqt_reset_simple_timers(void)
 #endif // HAVE_QT_WIN_USE_SIMPLE_TIMERS
 }
 
+// *************************************************************************
+
 #define ENVVAR_NOT_INITED INT_MAX
 
 int SoQtP::DEBUG_X11SYNC = ENVVAR_NOT_INITED;
@@ -334,6 +331,8 @@ SoQtP_XErrorHandler * SoQtP::previous_handler = NULL;
 
 int SoQtP::DEBUG_LISTMODULES = ENVVAR_NOT_INITED;
 
+// *************************************************************************
+
 // We're using the singleton pattern to create a single SoQtP object
 // instance (a dynamic object is needed for attaching slots to signals
 // -- this is really a workaround for some silliness in the Qt
@@ -453,7 +452,28 @@ SoQtP::slot_idleSensor()
   } 
 #endif // HAVE_QAPPLICATION_HASPENDINGEVENTS
 
-#ifdef HAVE_QAPPLICATION_HASPENDINGEVENTS  
+#ifdef HAVE_QAPPLICATION_HASPENDINGEVENTS
+#if 0 // This code has been disabled, because we discovered that for
+      // Qt 4 on MS Windows, there are *always* pending events when we
+      // get here. That seems to be against the documentation of
+      // QTimer::start(0), but when code talks, documentation walks.
+      //
+      // I disabled it completely, because I'm skeptical to whether or
+      // not it is really needed at all, even for Qt 3. If we however
+      // get reports of unacceptable latency in Qt handling GUI
+      // events, updating widgets, etc, we should probably choose to
+      // reenable it.
+      //
+      // If so, I suggest two changes:
+      //
+      // 1) only reenable it for Qt versions < 4
+      //
+      // 2) put in a counter which checks how many times in a row
+      //    we've returned without processing the queues, and do so
+      //    anyway if we get over a certain threshold
+      //
+      // --mortene.
+
   // If there are still events in the Qt event queue, push the
   // idle-timer at the end of the queue again.
   if (SoQtP::appobject->hasPendingEvents()) {
@@ -461,6 +481,7 @@ SoQtP::slot_idleSensor()
     SoQtP::idletimer->start(0, TRUE);
     return;
   }
+#endif
 #endif // HAVE_QAPPLICATION_HASPENDINGEVENTS
 
   SoDB::getSensorManager()->processTimerQueue();
@@ -724,16 +745,13 @@ SoQt::init(QWidget * toplevelwidget)
     return;
   }
 
-  SoQtObject::init();
+  SoAny::init();
 #ifdef COIN_IV_EXTENSIONS
 #define COIN_IV_EXTENSION(ext) ext::initClass();
   COIN_IV_EXTENSIONS
 #undef COIN_IV_EXTENSION
 #endif
 
-  SoGuiNodes::initClasses();
-  SoGuiEngines::initClasses();
-
   // This is _extremely_ useful for debugging X errors: activate this
   // code (set the SOQT_XSYNC environment variable on your system to
   // "1") and SOQT_X11_ERRORHANDLER to "1", then rerun the application
@@ -834,21 +852,34 @@ SoQt::mainLoop(void)
 {
   (void) qApp->exec();
 
+// Disabled invocation of SoQt::done(), since this calls SoDB::finish(), 
+// which means we would run into issues doing the usual...
+//    SoQt::mainLoop();
+//    root->unref();
+// FIXME: Is this what we want? Should the user explicitly have to call
+// SoQt::done()? If so, we should fix up our sample code to do so
+// too... 20060210 kyrah
+
+#if 0
   // The invocation of SoQt::done() used to be triggered from
   // atexit(), but this was changed as we were getting mysterious
   // crashes. No wonder, perhaps, as for all we know the Qt library is
   // cleaned up _before_ our atexit() methods are invoked.
   SoQt::done();
+#endif
 }
 
 // documented in common/SoGuiCommon.cpp.in
 void
 SoQt::exitMainLoop(void)
 {
+  // FIXME: Should we call SoQt::done() here? 20060210 kyrah 
   qApp->exit(0);
 }
 
 // documented in common/SoGuiCommon.cpp.in
+//
+// FIXME: in Mercury/TGS So*, this method is called finish(). 20051004 mortene.
 void
 SoQt::done(void)
 {
@@ -884,8 +915,16 @@ SoQt::done(void)
     const char * env = SoAny::si()->getenv("SOQT_DELETE_QAPPLICATION");
     if (env && atoi(env) > 0) {
       delete SoQtP::appobject; SoQtP::appobject = NULL;
+      SoQtP::madeappobject = FALSE;
     }
   }
+
+#if 0 // FIXME: These methods exist in TGS Inventor. We should add 
+      // them, and then call them from here. 20060210 kyrah
+  SoInteraction::finish();
+  SoNodeKit::finish();
+#endif
+  SoDB::finish();
 }
 
 
