@@ -28,10 +28,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif // HAVE_CONFIG_H
-
-// FIXME: get rid of this define. We should fix up the compile issues
-// wrt Qt 4 properly. 20050629 mortene.
-#define QT3_SUPPORT
+#include <qt-config.h>
 
 #include <qbitmap.h>
 #include <qwidget.h>
@@ -103,13 +100,29 @@ SoQtComponentP::cleanupQtReferences(void)
   this->parent->removeEventFilter(this);
 }
 
+static void delete_dict_value(unsigned long key, void * value)
+{
+  delete (QCursor *)value;
+}
+
+void
+SoQtComponentP::atexit_cleanup()
+{
+  if (SoQtComponentP::cursordict) {
+    SoQtComponentP::cursordict->applyToAll(delete_dict_value);
+    delete SoQtComponentP::cursordict;
+    SoQtComponentP::cursordict = NULL;
+  }
+}
+
 // Converts from the common generic cursor format to a QCursor
 // instance.
 QCursor *
 SoQtComponentP::getNativeCursor(const SoQtCursor::CustomCursor * cc)
 {
   if (SoQtComponentP::cursordict == NULL) { // first call, initialize
-    SoQtComponentP::cursordict = new SbDict; // FIXME: mem leak. 20011121 mortene.
+    SoQtComponentP::cursordict = new SbDict;
+    sogui_atexit((sogui_atexit_f*)SoQtComponentP::atexit_cleanup, 0);
   }
 
   void * qc;
@@ -154,7 +167,6 @@ SoQtComponentP::getNativeCursor(const SoQtCursor::CustomCursor * cc)
   assert(bitmap.depth() == 1);
   assert(mask.depth() == 1);
 
-  // FIXME: currently a memory leak here. 20011121 mortene.
   QCursor * c = new QCursor(bitmap, mask, cc->hotspot[0], cc->hotspot[1]);
   SoQtComponentP::cursordict->enter((unsigned long)cc, c);
   return c;
@@ -541,19 +553,16 @@ SoQtComponent::show(void)
 
   PRIVATE(this)->widget->raise();
 
-  // FIXME: This is a very, very ugly workaround to force Qt 3.3.x on
-  // Mac OS X to repaint our component on startup. Otherwise, all you
-  // get is a blank white window. The problem seems to be related to a
-  // paint event "getting lost" somewhere (it's registered in
-  // SoQtComponent but never makes it to SoQtGLWidget.) This should
-  // really be fixed properly but I guess it's better to have things
-  // working in the meantime...
-  // Note that this workaround is a weird thing in itself: calling
-  // raise() twice should not make a difference, since raise() puts
-  // the widget to the top of the stack so that "the widget will be
-  // visually in front of any overlapping sibling widgets". 
-  // kyrah 20040211.
-#if (defined Q_WS_MAC && QT_VERSION >= 0x030300)
+  // Workaround for a bug Qt version 3.3.0 -3.3.3 on Mac OS X.
+  // Without this, a standalone examinerviewer gets displayed as a
+  // completely blank white window. The problem seems to be related to
+  // a paint event "getting lost" somewhere (it's registered in
+  // SoQtComponent but never makes it to SoQtGLWidget.)  Note that
+  // this workaround is a weird thing in itself: calling raise() twice
+  // should not make a difference, since raise() puts the widget to
+  // the top of the stack so that "the widget will be visually in
+  // front of any overlapping sibling widgets".
+#if (defined Q_WS_MAC && QT_VERSION >= 0x030300 && QT_VERSION < 0x030304)
   PRIVATE(this)->widget->raise();
 #endif // Q_WS_MAC
 
