@@ -58,10 +58,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif // HAVE_CONFIG_H
-
-// FIXME: get rid of this define. We should fix up the compile issues
-// wrt Qt 4 properly. 20050629 mortene.
-#define QT3_SUPPORT
+#include <qt-config.h>
 
 #include <stdlib.h>
 
@@ -987,7 +984,7 @@ SoQtGLWidgetP::buildGLWidget(void)
 
   // the following Qt methods are only available under X11
   display = (void*) QPaintDevice::x11AppDisplay();
-  screen = (void*) ((unsigned int) QPaintDevice::x11AppScreen());
+  screen = (void*) ((unsigned long) QPaintDevice::x11AppScreen());
 #endif // Q_WS_X11
 
   if (wascurrent) {
