@@ -24,49 +24,43 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif // HAVE_CONFIG_H
-
-// FIXME: get rid of this define. We should fix up the compile issues
-// wrt Qt 4 properly. 20050629 mortene.
-#define QT3_SUPPORT
+#include <qt-config.h>
 
 #include <qevent.h>
 #include <qnamespace.h>
 
 #include <Inventor/SbDict.h>
+#include <Inventor/errors/SoDebugError.h>
 #include <Inventor/events/SoKeyboardEvent.h>
 
-#include <Inventor/Qt/devices/SoQtKeyboard.h>
 #include <Inventor/Qt/devices/SoGuiKeyboardP.h>
-#include <Inventor/errors/SoDebugError.h>
+#include <Inventor/Qt/devices/SoQtKeyboard.h>
 
-// The reason for this is that SoQt _compiled_ against Qt versions
-// 2.0.0 <= X < 2.2.0 should still detect keypad presses when _run_
-// against Qt versions >= 2.2.0.
-#define QT_KEYPAD_MASK_ASSUMED 0x4000
+// *************************************************************************
 
 #if defined(Q_WS_MAC) || (defined(__APPLE__) && defined(Q_WS_X11))
 #define QT_ON_MAC 1
 #endif
 
-#if HAVE_QT_KEYPAD_DEFINE
+/*
+  The Qt::Keypad define was not added in Qt until version 2.2.0.
+
+  We still want to use it when building against earlier versions, as
+  SoQt would then be able to still work properly in this regard when
+  built against earlier Qt 2-versions, while run on later Qt
+  2-versions.
+
+  (To keep ABI compatibility, it had to be the same for all 2.x.y
+  releases.)
+*/
+#if (QT_VERSION >= 0x030000)
 #define QT_KEYPAD_MASK Qt::Keypad
-#else // !HAVE_QT_KEYPAD_DEFINE
-#define QT_KEYPAD_MASK QT_KEYPAD_MASK_ASSUMED
-#endif // !HAVE_QT_KEYPAD_DEFINE
+#else // Qt ver < 3.0.0
+#define QT_KEYPAD_MASK 0x4000
+#endif // Qt ver < 3.0.0
 
 // *************************************************************************
 
-#if QT_VERSION < 200
-#error Qt version too old!
-#endif // QT_VERSION < 200
-
-// *************************************************************************
-
-#define PRIVATE(obj) ((obj)->pimpl)
-#define PUBLIC(obj) ((obj)->pub)
-
-#ifndef DOXYGEN_SKIP_THIS
-
 class SoQtKeyboardP : public SoGuiKeyboardP {
 public:
   struct key1map {
@@ -242,13 +236,18 @@ struct SoQtKeyboardP::key1map SoQtKeyboardP::QtToSoMapping_kp[] = {
 SbDict * SoQtKeyboardP::translatetable = NULL;
 SbDict * SoQtKeyboardP::kp_translatetable = NULL;
 
-#endif // !DOXYGEN_SKIP_THIS
+#define PRIVATE(obj) ((obj)->pimpl)
+#define PUBLIC(obj) ((obj)->pub)
+
+// *************************************************************************
 
 static void
 soqtkeyboard_cleanup(void)
 {
   delete SoQtKeyboardP::translatetable;
+  SoQtKeyboardP::translatetable = NULL;
   delete SoQtKeyboardP::kp_translatetable;
+  SoQtKeyboardP::kp_translatetable = NULL;
 }
 
 // *************************************************************************
@@ -256,16 +255,7 @@ soqtkeyboard_cleanup(void)
 SoQtKeyboard::SoQtKeyboard(int mask)
 {
   PRIVATE(this) = new SoQtKeyboardP;
-
   PRIVATE(this)->eventmask = mask;
-
-  // Protect against surprises in future Qt version (>= v3).
-  static bool mask_tested = false;
-  if (!mask_tested) {
-    mask_tested = true;
-    assert((QT_KEYPAD_MASK == QT_KEYPAD_MASK_ASSUMED) &&
-           "value of Qt::Keypad has changed!");
-  }
 }
 
 SoQtKeyboard::~SoQtKeyboard()
