@@ -1,7 +1,7 @@
 /**************************************************************************\
  *
  *  This file is part of the Coin 3D visualization library.
- *  Copyright (C) 1998-2004 by Systems in Motion.  All rights reserved.
+ *  Copyright (C) 1998-2005 by Systems in Motion.  All rights reserved.
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
@@ -16,7 +16,7 @@
  *
  *  See <URL:http://www.coin3d.org/> for more information.
  *
- *  Systems in Motion, Teknobyen, Abels Gate 5, 7030 Trondheim, NORWAY.
+ *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
  *  <URL:http://www.sim.no/>.
  *
 \**************************************************************************/
@@ -25,15 +25,21 @@
 #include <config.h>
 #endif // HAVE_CONFIG_H
 
+// FIXME: get rid of this define. We should fix up the compile issues
+// wrt Qt 4 properly. 20050629 mortene.
+#define QT3_SUPPORT
+
+#include <qwidget.h>
+
+#include <Inventor/events/SoMotion3Event.h>
+#include <Inventor/events/SoSpaceballButtonEvent.h>
+
 #include <soqtdefs.h>
 #include <Inventor/Qt/SoQt.h>
 #include <Inventor/Qt/SoQtBasic.h>
 #include <Inventor/Qt/devices/SoQtSpaceball.h>
 #include <Inventor/Qt/devices/SoQtSpaceballP.h>
 #include <Inventor/Qt/SoQtInternal.h>
-#include <Inventor/events/SoMotion3Event.h>
-#include <Inventor/events/SoSpaceballButtonEvent.h>
-#include <qwidget.h>
 
 /* The setting of this define needs to be added manually to
    configure.in for all relevant projects. */
@@ -108,13 +114,13 @@ SoQtSpaceball::enable(QWidget * widget, SoQtEventHandler * handler, void * closu
 {
 #ifdef HAVE_X11_AVAILABLE
   static char sbtestx[] = "sbtestx";
-  if (SPW_CheckForSpaceballX11((void*) widget->x11Display(),
-                               widget->winId(), sbtestx) == TRUE) {
+  if (((int) SPW_CheckForSpaceballX11((void*) widget->x11Display(),
+                               widget->winId(), sbtestx)) != FALSE) {
   }
 #endif // HAVE_X11_AVAILABLE
 
 #ifdef HAVE_WIN32_API
-  if (SPW_CheckForSpaceballWin32(widget->winId()) == TRUE) {
+  if (((int) SPW_CheckForSpaceballWin32(widget->winId())) != FALSE) {
     
   }
 #endif // HAVE_WIN32_API
