@@ -41,10 +41,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif // HAVE_CONFIG_H
-
-// FIXME: get rid of this define. We should fix up the compile issues
-// wrt Qt 4 properly. 20050629 mortene.
-#define QT3_SUPPORT
+#include <qt-config.h>
 
 #include <qbuttongroup.h>
 #include <qcheckbox.h>
