@@ -1,7 +1,10 @@
+#ifndef SOQT_THUMBWHEEL_H
+#define SOQT_THUMBWHEEL_H
+
 /**************************************************************************\
  *
  *  This file is part of the Coin 3D visualization library.
- *  Copyright (C) 1998-2004 by Systems in Motion.  All rights reserved.
+ *  Copyright (C) 1998-2005 by Systems in Motion.  All rights reserved.
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
@@ -16,16 +19,12 @@
  *
  *  See <URL:http://www.coin3d.org/> for more information.
  *
- *  Systems in Motion, Teknobyen, Abels Gate 5, 7030 Trondheim, NORWAY.
+ *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
  *  <URL:http://www.sim.no/>.
  *
 \**************************************************************************/
 
-#ifndef SOQT_THUMBWHEEL_H
-#define SOQT_THUMBWHEEL_H
-
 #include <qwidget.h>
-#include <qrangecontrol.h>
 
 #include <Inventor/Qt/SoQtBasic.h>
 
@@ -34,7 +33,7 @@ class SoAnyThumbWheel;
 
 // *************************************************************************
 
-class SOQT_DLL_API SoQtThumbWheel : public QWidget, public QRangeControl
+class SOQT_DLL_API SoQtThumbWheel : public QWidget
 {
   Q_OBJECT
 
